==> sklonenie-0.0.1.tgz: package/test/test.js <==
const sklonenie = require('../js/sklonenie');
const mocha     = require('mocha');
const expect    = require('chai').expect;

var cases = sklonenie.prototype.cases;
describe("Склонение имён", function() {
    var testObj = {
        'Александр':  ['Александра', 'Александру', 'Александра', 'Александром', 'Александре', 1],
        'Александра': ['Александры', 'Александре', 'Александру', 'Александрой', 'Александре', 2],
        'Николай':    ['Николая',    'Николаю',    'Николая',    'Николаем',    'Николае',    0],
        'Павел':      ['Павла',      'Павлу',      'Павла',      'Павлом',      'Павле',      0],
        'Вильгельм':  ['Вильгельма', 'Вильгельму', 'Вильгельма', 'Вильгельмом', 'Вильгельме', 0],
        'Петр':       ['Петра',      'Петру',      'Петра',      'Петром',      'Петре',      0],
        'Иван':       ['Ивана',      'Ивану',      'Ивана',      'Иваном',      'Иване',      0],
        'Дмитрий':    ['Дмитрия',    'Дмитрию',    'Дмитрия',    'Дмитрием',    'Дмитрии',    1],
        'Афанасий':   ['Афанасия',   'Афанасию',   'Афанасия',   'Афанасием',   'Афанасии',   1],
        'Лев':        ['Льва',       'Льву',       'Льва',       'Львом',       'Льве',       0],
        'Лидия':      ['Лидии',      'Лидии',      'Лидию',      'Лидией',      'Лидии',      2],
        'Авдотья':    ['Авдотьи',    'Авдотье',    'Авдотью',    'Авдотьей',    'Авдотье',    2],
        'Анна':       ['Анны',       'Анне',       'Анну',       'Анной',       'Анне',       2],
        'Зинаида':    ['Зинаиды',    'Зинаиде',    'Зинаиду',    'Зинаидой',    'Зинаиде',    2],
        'Любовь':     ['Любови',     'Любови',     'Любовь',     'Любовью',     'Любови',     2],
        'Адель':      ['Аделя',      'Аделю',      'Аделя',      'Аделем',      'Аделе',      1],
        'Адель':      ['Адели',      'Адели',      'Адель',      'Аделью',      'Адели',      2],
        'Иракли':     ['Иракли',     'Иракли',     'Иракли',     'Иракли',      'Иракли',     0],
    };

    it('Именительный', function() {
        for(var str in testObj) {
            expect(str).to.be.ok;
        }
    });

    var c = ['Родительный', 'Дательный', 'Винительный', 'Предложный'];

    for (var i = 0; i < c.length; i++) {
        it(c[i], function() {

            for(var str in testObj) {
                var testArr = testObj[str];
                var gender =  + testArr[testArr.length - 1] || 0;

                expect(
                    sklonenie(str,'','', gender).firstname[i + 1]
                ).to.equal(testObj[str][i])
            }
        });
    }
});

describe("Склонение отчеств", function() {
    var testObj = {
        'Викторовна': ['Викторовны',  'Викторовне',  'Викторовну',  'Викторовной',  'Викторовне'],
        'Робертович': ['Робертовича', 'Робертовичу', 'Робертовича', 'Робертовичем', 'Робертовиче'],
        'Василич':    ['Василича',    'Василичу',    'Василича',    'Василича',     'Василиче'],
        'Ариф':       ['Ариф',        'Ариф',        'Ариф',        'Ариф',         'Ариф'],
    };

    it('Именительный', function() {
        for(var str in testObj) {
            expect(str).to.be.ok;
        }
    });

    var c = ['Родительный', 'Дательный', 'Винительный', 'Предложный'];

    for (var i = 0; i < c.length; i++) {
        it(c[i], function() {

            for(var str in testObj) {
                var testArr = testObj[str];
                expect(
                    sklonenie.middleName(str)[i + 1]
                ).to.equal(testObj[str][i])
            }
        });
    }
});

describe("Склонение фамилий", function() {
    var testObj = {
        'Пушкин':      ['Пушкина',      'Пушкину',      'Пушкина',      'Пушкиным',      'Пушкине',      1],
        'Островский':  ['Островского',  'Островскому',  'Островского',  'Островским',    'Островском',   1],
        'Гнедич':      ['Гнедича',      'Гнедичу',      'Гнедича',      'Гнедичем',      'Гнедиче',      1],
        'Крылов':      ['Крылова',      'Крылову',      'Крылова',      'Крыловым',      'Крылове',      1],
        'Грибоедов':   ['Грибоедова',   'Грибоедову',   'Грибоедова',   'Грибоедовым',   'Грибоедове',   1],
        'Глинка':      ['Глинки',       'Глинке',       'Глинку',       'Глинкой',       'Глинке',       1],
        'Пестель':     ['Пестеля',      'Пестелю',      'Пестеля',      'Пестелем',      'Пестеле',      1],
        'Дельвиг':     ['Дельвига',     'Дельвигу',     'Дельвига',     'Дельвигом',     'Дельвиге',     1],
        'Кюхельбекер': ['Кюхельбекера', 'Кюхельбекеру', 'Кюхельбекера', 'Кюхельбекером', 'Кюхельбекере', 1],
        'Вяземский':   ['Вяземского',   'Вяземскому',   'Вяземского',   'Вяземским',     'Вяземском',    1],
        'Даль':        ['Даля',         'Далю',         'Даля',         'Далем',         'Дале',         1],
        'Лермонтов':   ['Лермонтова',   'Лермонтову',   'Лермонтова',   'Лермонтовым',   'Лермонтове',   1],
        'Гоголь':      ['Гоголя',       'Гоголю',       'Гоголя',       'Гоголем',       'Гоголе',       1],
        'Герцен':      ['Герцена',      'Герцену',      'Герцена',      'Герценым',      'Герцене',      1],
        'Огарев':      ['Огарева',      'Огареву',      'Огарева',      'Огаревым',      'Огареве',      1],
        'Тургенев':    ['Тургенева',    'Тургеневу',    'Тургенева',    'Тургеневым',    'Тургеневе',    1],
        'Григорович':  ['Григоровича',  'Григоровичу',  'Григоровича',  'Григоровичем',  'Григоровиче',  1],
        'Фет':         ['Фета',         'Фету',         'Фета',         'Фетом',         'Фете',         1],
        'Толстой':     ['Толстого',     'Толстому',     'Толстого',     'Толстым',       'Толстом',      1],
        'Достоевский': ['Достоевского', 'Достоевскому', 'Достоевского', 'Достоевским',   'Достоевском',  1],
        'Чехов':       ['Чехова',       'Чехову',       'Чехова',       'Чеховым',       'Чехове',       1],
        'Седых':       ['Седых',        'Седых',        'Седых',        'Седых',         'Седых',        1],
        'Гёте':        ['Гёте',         'Гёте',         'Гёте',         'Гёте',          'Гёте',         1],
        'Бах':         ['Баха',         'Баху',         'Баха',         'Бахом',         'Бахе',         1],
        'Ахматова':    ['Ахматовой',    'Ахматовой',    'Ахматовой',    'Ахматовой',     'Ахматовой',    2],
        'Авилова':     ['Авиловой',     'Авиловой',     'Авиловой',     'Авиловой',      'Авиловой',     2],
        'Павлова':     ['Павловой',     'Павловой',     'Павловой',     'Павловой',      'Павловой',     2],
        'Берггольц':   ['Берггольц',    'Берггольц',    'Берггольц',    'Берггольц',     'Берггольц',    2],
        'Панаева':     ['Панаевой',     'Панаевой',     'Панаевой',     'Панаевой',      'Панаевой',     2],
        'Бунина':      ['Буниной',      'Буниной',      'Буниной',      'Буниной',       'Буниной',      2],
        'Волконская':  ['Волконской',   'Волконской',   'Волконской',   'Волконской',    'Волконской',   2],
        'Гиппиус':     ['Гиппиус',      'Гиппиус',      'Гиппиус',      'Гиппиус',       'Гиппиус',      2]
    };

    it('Именительный', function() {
        for(var str in testObj) {
            expect(str).to.be.ok;
        }
    });

    var c = ['Родительный', 'Дательный', 'Винительный', 'Предложный'];
    for (var i = 0; i < c.length; i++) {
        it(c[i], function() {
            for(var str in testObj) {
                var testArr = testObj[str];
                var gender =  + testArr[testArr.length - 1] || 0;

                expect(
                    sklonenie.lastName(str, gender)[i + 1]
                ).to.equal(testObj[str][i])
            }
        });
    }
});

==> sklonenie-0.0.2.tgz: package/test/test.js <==
const sklonenie = require('../js/sklonenie');
const mocha     = require('mocha');
const expect    = require('chai').expect;

var cases = sklonenie.prototype.cases;
describe("Склонение имён", function() {
    var testObj = {
        'Александр':  ['Александра', 'Александру', 'Александра', 'Александром', 'Александре', 1],
        'Александра': ['Александры', 'Александре', 'Александру', 'Александрой', 'Александре', 2],
        'Николай':    ['Николая',    'Николаю',    'Николая',    'Николаем',    'Николае',    0],
        'Павел':      ['Павла',      'Павлу',      'Павла',      'Павлом',      'Павле',      0],
        'Вильгельм':  ['Вильгельма', 'Вильгельму', 'Вильгельма', 'Вильгельмом', 'Вильгельме', 0],
        'Петр':       ['Петра',      'Петру',      'Петра',      'Петром',      'Петре',      0],
        'Иван':       ['Ивана',      'Ивану',      'Ивана',      'Иваном',      'Иване',      0],
        'Дмитрий':    ['Дмитрия',    'Дмитрию',    'Дмитрия',    'Дмитрием',    'Дмитрии',    1],
        'Афанасий':   ['Афанасия',   'Афанасию',   'Афанасия',   'Афанасием',   'Афанасии',   1],
        'Лев':        ['Льва',       'Льву',       'Льва',       'Львом',       'Льве',       0],
        'Лидия':      ['Лидии',      'Лидии',      'Лидию',      'Лидией',      'Лидии',      2],
        'Авдотья':    ['Авдотьи',    'Авдотье',    'Авдотью',    'Авдотьей',    'Авдотье',    2],
        'Анна':       ['Анны',       'Анне',       'Анну',       'Анной',       'Анне',       2],
        'Зинаида':    ['Зинаиды',    'Зинаиде',    'Зинаиду',    'Зинаидой',    'Зинаиде',    2],
        'Любовь':     ['Любови',     'Любови',     'Любовь',     'Любовью',     'Любови',     2],
        'Адель':      ['Аделя',      'Аделю',      'Аделя',      'Аделем',      'Аделе',      1],
        'Адель':      ['Адели',      'Адели',      'Адель',      'Аделью',      'Адели',      2],
        'Иракли':     ['Иракли',     'Иракли',     'Иракли',     'Иракли',      'Иракли',     0],
    };

    it('Именительный', function() {
        for(var str in testObj) {
            expect(str).to.be.ok;
        }
    });

    var c = ['Именительный', 'Родительный', 'Дательный', 'Винительный', 'Творительный', 'Предложный'];

    for (var i = 1; i < c.length; i++) {
        it(c[i], function() {
            for(var str in testObj) {
                var testArr = testObj[str];
                var gender =  + testArr[testArr.length - 1] || 0;

                expect(
                    sklonenie(str,'','', gender).firstname[i + 1]
                ).to.equal(testObj[str][i])
            }
        });
    }
});

describe("Склонение отчеств", function() {
    var testObj = {
        'Ильинична':  ['Ильиничны',   'Ильиничне',   'Ильиничну',   'Ильиничной',   'Ильиничне'],
        'Викторовна': ['Викторовны',  'Викторовне',  'Викторовну',  'Викторовной',  'Викторовне'],
        'Робертович': ['Робертовича', 'Робертовичу', 'Робертовича', 'Робертовичем', 'Робертовиче'],
        'Василич':    ['Василича',    'Василичу',    'Василича',    'Василича',     'Василиче'],
        'Ариф':       ['Ариф',        'Ариф',        'Ариф',        'Ариф',         'Ариф'],
    };

    it('Именительный', function() {
        for(var str in testObj) {
            expect(str).to.be.ok;
        }
    });

    var c = ['Именительный', 'Родительный', 'Дательный', 'Винительный', 'Творительный', 'Предложный'];

    for (var i = 1; i < c.length; i++) {
        it(c[i], function() {

            for(var str in testObj) {
                var testArr = testObj[str];
                expect(
                    sklonenie.middleName(str)[i + 1]
                ).to.equal(testObj[str][i])
            }
        });
    }
});

describe("Склонение фамилий", function() {
    var testObj = {
        'Пушкин':      ['Пушкина',      'Пушкину',      'Пушкина',      'Пушкиным',      'Пушкине',      1],
        'Островский':  ['Островского',  'Островскому',  'Островского',  'Островским',    'Островском',   1],
        'Гнедич':      ['Гнедича',      'Гнедичу',      'Гнедича',      'Гнедичем',      'Гнедиче',      1],
        'Крылов':      ['Крылова',      'Крылову',      'Крылова',      'Крыловым',      'Крылове',      1],
        'Грибоедов':   ['Грибоедова',   'Грибоедову',   'Грибоедова',   'Грибоедовым',   'Грибоедове',   1],
        'Глинка':      ['Глинки',       'Глинке',       'Глинку',       'Глинкой',       'Глинке',       1],
        'Пестель':     ['Пестеля',      'Пестелю',      'Пестеля',      'Пестелем',      'Пестеле',      1],
        'Дельвиг':     ['Дельвига',     'Дельвигу',     'Дельвига',     'Дельвигом',     'Дельвиге',     1],
        'Кюхельбекер': ['Кюхельбекера', 'Кюхельбекеру', 'Кюхельбекера', 'Кюхельбекером', 'Кюхельбекере', 1],
        'Вяземский':   ['Вяземского',   'Вяземскому',   'Вяземского',   'Вяземским',     'Вяземском',    1],
        'Даль':        ['Даля',         'Далю',         'Даля',         'Далем',         'Дале',         1],
        'Лермонтов':   ['Лермонтова',   'Лермонтову',   'Лермонтова',   'Лермонтовым',   'Лермонтове',   1],
        'Гоголь':      ['Гоголя',       'Гоголю',       'Гоголя',       'Гоголем',       'Гоголе',       1],
        'Герцен':      ['Герцена',      'Герцену',      'Герцена',      'Герценым',      'Герцене',      1],
        'Огарев':      ['Огарева',      'Огареву',      'Огарева',      'Огаревым',      'Огареве',      1],
        'Тургенев':    ['Тургенева',    'Тургеневу',    'Тургенева',    'Тургеневым',    'Тургеневе',    1],
        'Григорович':  ['Григоровича',  'Григоровичу',  'Григоровича',  'Григоровичем',  'Григоровиче',  1],
        'Фет':         ['Фета',         'Фету',         'Фета',         'Фетом',         'Фете',         1],
        'Толстой':     ['Толстого',     'Толстому',     'Толстого',     'Толстым',       'Толстом',      1],
        'Достоевский': ['Достоевского', 'Достоевскому', 'Достоевского', 'Достоевским',   'Достоевском',  1],
        'Чехов':       ['Чехова',       'Чехову',       'Чехова',       'Чеховым',       'Чехове',       1],
        'Седых':       ['Седых',        'Седых',        'Седых',        'Седых',         'Седых',        1],
        'Гёте':        ['Гёте',         'Гёте',         'Гёте',         'Гёте',          'Гёте',         1],
        'Бах':         ['Баха',         'Баху',         'Баха',         'Бахом',         'Бахе',         1],
        'Ахматова':    ['Ахматовой',    'Ахматовой',    'Ахматовой',    'Ахматовой',     'Ахматовой',    2],
        'Авилова':     ['Авиловой',     'Авиловой',     'Авиловой',     'Авиловой',      'Авиловой',     2],
        'Павлова':     ['Павловой',     'Павловой',     'Павловой',     'Павловой',      'Павловой',     2],
        'Берггольц':   ['Берггольц',    'Берггольц',    'Берггольц',    'Берггольц',     'Берггольц',    2],
        'Панаева':     ['Панаевой',     'Панаевой',     'Панаевой',     'Панаевой',      'Панаевой',     2],
        'Бунина':      ['Буниной',      'Буниной',      'Буниной',      'Буниной',       'Буниной',      2],
        'Волконская':  ['Волконской',   'Волконской',   'Волконской',   'Волконской',    'Волконской',   2],
        'Гиппиус':     ['Гиппиус',      'Гиппиус',      'Гиппиус',      'Гиппиус',       'Гиппиус',      2]
    };

    it('Именительный', function() {
        for(var str in testObj) {
            expect(str).to.be.ok;
        }
    });

    var c = ['Именительный', 'Родительный', 'Дательный', 'Винительный', 'Творительный', 'Предложный'];

    for (var i = 1; i < c.length; i++) {
        it(c[i], function() {
            for(var str in testObj) {
                var testArr = testObj[str];
                var gender =  + testArr[testArr.length - 1] || 0;

                expect(
                    sklonenie.lastName(str, gender)[i + 1]
                ).to.equal(testObj[str][i])
            }
        });
    }
});
